@@ -34,10 +34,6 @@ function exec_mutualisation_dist() {
 	$url_admin_plugin = 'ecrire/?exec=admin_plugin';
 	$url_admin_vider = 'ecrire/?exec=admin_vider';
 
-	if (!file_exists(_DIR_IMG . 'mutualiser-128.png')) {
-		@copy(find_in_path('mutualiser-128.png'), _DIR_IMG . 'mutualiser-128.png');
-	}
-
 	$titre = _L(count($sites) . ' ' . 'sites mutualis&#233;s <em>(' . _T('version') . ' ' . $GLOBALS['spip_version_base'] . ')</em>');
 
 	//$page .= "<div id='trace'></div>" ;
@@ -151,9 +147,9 @@ function exec_mutualisation_dist() {
 			if ($compression == '') {
 				$compression = _L('Activer');
 			}
+			$configsparticulieres = '';
 			if (isset($GLOBALS['mutualisation_afficher_config'])) {
 				$configs = explode(",", $GLOBALS['mutualisation_afficher_config']);
-				$configsparticulieres = '';
 				foreach ($configs as $config) {
 
 					$configsparticulieres .= '<em><small>' . $config . ':</small></em> ' . lire_config_distante($config, $meta) . "<br />\n";
@@ -176,8 +172,8 @@ function exec_mutualisation_dist() {
             <td><div id='IMG$nsite' class='taille loading'></div></td>\n
             <td><div id='local$nsite' class='taille loading'></div></td>\n
             <td><div id='cache$nsite' class='taille loading'></div></td>\n
-            <td class='text-right'><a href='" . $url . "$url_stats'>${stats}</a></td>\n
-            <td>$adminplugin<div class='liste-plugins'><a href='" . $url . "$url_admin_plugin'>${cntplugins}</a> <small>${plugins}</small></div></td>\n
+            <td class='text-right'><a href='" . $url . "$url_stats'>{$stats}</a></td>\n
+            <td>$adminplugin<div class='liste-plugins'><a href='" . $url . "$url_admin_plugin'>{$cntplugins}</a> <small>{$plugins}</small></div></td>\n
             <td><a href='" . $url . "$url_compresseur'>$compression</a></td>\n
             <td>$configsparticulieres</td>\n
             <td class='text-right'>" . date_creation_repertoire_site($v) . "</td>\n
@@ -226,17 +222,17 @@ function exec_mutualisation_dist() {
 				. "\n"
 				. '</tr>'
 				. "\n";
-			if ($_GET['tri'] AND isset($plnum[intval(count($c))])) {
+			if (!empty($_GET['tri']) AND isset($plnum[intval(count($c))])) {
 				$plnum[intval(count($c))] .= $ligne;
 			} else {
-				if ($_GET['tri']) {
+				if (!empty($_GET['tri'])) {
 					$plnum[intval(count($c))] = $ligne;
 				} else {
 					$plnum[] = $ligne;
 				}
 			}
 		}
-		if ($_GET['tri']) {
+		if (!empty($_GET['tri'])) {
 			krsort($plnum);
 		}
 		$page .= implode('', $plnum);
@@ -398,9 +394,9 @@ function exec_mutualisation_dist() {
 	$debug_toolbar .= "<div class='toolbar-icon'><i class='icon-time'></i> <span>" . $page_load_time . " s</span></div>\n";
 	$debug_toolbar .= "<div class='toolbar-info'>";
 	$debug_toolbar .= "<div class='toolbar-info-element'><b>Début du script</b> <span>" . date('H:i:s',
-			$timestart) . "</span></div>\n";
+			(int) $timestart) . "</span></div>\n";
 	$debug_toolbar .= "<div class='toolbar-info-element'><b>Fin du script</b> <span>" . date('H:i:s',
-			$timeend) . "</span></div>\n";
+			(int) $timeend) . "</span></div>\n";
 	$debug_toolbar .= "<div class='toolbar-info-element'><b>Temps d'exécution</b> <span>" . $page_load_time . " s</span></div>\n";
 	$debug_toolbar .= "</div></div>\n";
 
@@ -590,7 +586,7 @@ function processConfig(&$cfg, &$lsplugs, $path) {
 	return false;
 }
 
-function lire_config_distante($cfg = '', $meta) {
+function lire_config_distante($cfg = '', $meta = '') {
 	$def = null;
 	$unserialize = true;
 	// lire le stockage sous la forme valeur
@@ -611,8 +607,8 @@ function lire_config_distante($cfg = '', $meta) {
 		return $r;
 	} else {
 		$cfg = explode('/', $cfg);
-		$r = @unserialize($meta[$cfg[0]]);
-		$r = $r[$cfg[1]];
+		$r = unserialize($meta[$cfg[0]] ?? '');
+		$r = $r[$cfg[1]] ?? '';
 
 		return $r;
 	}
