@@ -5,14 +5,12 @@
 //	    où rep1, rep2,... le nom des sous-répertoires
 // Param dir : répertoire à explorer
 
-if (!defined("_ECRIRE_INC_VERSION"))
+if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
+}
 
-echo dirliste($_GET['dir']);
-
-function dirliste($path)
-{
-	$liste = "";
+function dirliste($path) {
+	$liste = '';
 	$size = 0;
 
 	// Trailing slash
@@ -20,26 +18,26 @@ function dirliste($path)
 		$path .= DIRECTORY_SEPARATOR;
 	}
 
-	if (!is_dir($path))
+	if (!is_dir($path)) {
 		return -1;
+	}
 
-	$handle=opendir($path) ;
+	$handle = opendir($path);
 	while (($file = readdir($handle)) !== false) {
 		// Skip pointers
-		if ($file == '.' || $file == '..')
+		if ($file == '.' || $file == '..') {
 			continue;
+		}
 
-		if (is_dir($path.$file)) {
-			$liste .= '##'.$file;
-		} elseif (is_file($path.$file)) {
-			$size += filesize($path.$file);
+		if (is_dir($path . $file)) {
+			$liste .= '##' . $file;
+		} elseif (is_file($path . $file)) {
+			$size += filesize($path . $file);
 		} else {
 			echo $file;
 		}
 	}
-	closedir($handle) ;
+	closedir($handle);
 
-	return round($size/1024/1024,2).$liste;
+	return round($size/1024/1024, 2) . $liste;
 }
-
-?>
\ No newline at end of file
